@@ -1,7 +1,7 @@
 // qpwgraph_alsamidi.h
 //
 /****************************************************************************
-   Copyright (C) 2021-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2021-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -100,7 +100,7 @@ private:
 	QSocketNotifier *m_notifier;
 
 	// Notifier sanity mutex.
-	static QMutex g_mutex;
+	QMutex m_mutex;
 };
 
 
