@@ -107,11 +107,7 @@ qpwgraph_form::qpwgraph_form (
 	m_ui.graphCanvas->setSettings(m_config->settings());
 
 	m_pipewire = new qpwgraph_pipewire(m_ui.graphCanvas);
-#ifdef CONFIG_ALSA_MIDI
-	m_alsamidi = new qpwgraph_alsamidi(m_ui.graphCanvas);
-#else
 	m_alsamidi = nullptr;
-#endif
 
 	m_pipewire_changed = 0;
 	m_alsamidi_changed = 0;
@@ -202,13 +198,7 @@ qpwgraph_form::qpwgraph_form (
 			SIGNAL(changed()),
 			SLOT(pipewire_changed()));
 	}
-#ifdef CONFIG_ALSA_MIDI
-	if (m_alsamidi) {
-		QObject::connect(m_alsamidi,
-			SIGNAL(changed()),
-			SLOT(alsamidi_changed()));
-	}
-#endif
+
 	QObject::connect(m_ui.graphCanvas,
 		SIGNAL(added(qpwgraph_node *)),
 		SLOT(added(qpwgraph_node *)));
@@ -287,6 +277,9 @@ qpwgraph_form::qpwgraph_form (
 	QObject::connect(m_ui.patchbayAutoPinAction,
 		SIGNAL(toggled(bool)),
 		SLOT(patchbayAutoPin(bool)));
+	QObject::connect(m_ui.patchbayAutoDisconnectAction,
+		SIGNAL(toggled(bool)),
+		SLOT(patchbayAutoDisconnect(bool)));
 
 	QObject::connect(m_ui.patchbayEditAction,
 		SIGNAL(toggled(bool)),
@@ -435,13 +428,25 @@ qpwgraph_form::qpwgraph_form (
 #ifdef CONFIG_SYSTEM_TRAY
 	m_ui.helpMenu->insertAction(
 		m_ui.helpAboutAction, m_ui.helpSystemTrayAction);
+#ifndef CONFIG_ALSA_MIDI
 	m_ui.helpMenu->insertSeparator(
 		m_ui.helpAboutAction);
+#endif
 	QObject::connect(m_ui.helpSystemTrayAction,
 		SIGNAL(triggered(bool)),
 		SLOT(helpSystemTray(bool)));
 #endif
 
+#ifdef CONFIG_ALSA_MIDI
+	m_ui.helpMenu->insertAction(
+		m_ui.helpAboutAction, m_ui.helpAlsaMidiAction);
+	m_ui.helpMenu->insertSeparator(
+		m_ui.helpAboutAction);
+	QObject::connect(m_ui.helpAlsaMidiAction,
+		 SIGNAL(triggered(bool)),
+		 SLOT(helpAlsaMidi(bool)));
+#endif
+
 	QObject::connect(m_ui.helpAboutAction,
 		SIGNAL(triggered(bool)),
 		SLOT(helpAbout()));
@@ -637,8 +642,7 @@ void qpwgraph_form::patchbayActivated ( bool on )
 	qpwgraph_patchbay *patchbay = m_ui.graphCanvas->patchbay();
 	if (patchbay) {
 		patchbay->setActivated(on);
-		if (on)
-			patchbay->scan();
+		patchbay->scan();
 	}
 
 	stabilize();
@@ -650,7 +654,7 @@ void qpwgraph_form::patchbayExclusive ( bool on )
 	qpwgraph_patchbay *patchbay = m_ui.graphCanvas->patchbay();
 	if (patchbay) {
 		patchbay->setExclusive(on);
-		if (on)
+		if (patchbay->isActivated())
 			patchbay->scan();
 	}
 
@@ -690,6 +694,14 @@ void qpwgraph_form::patchbayAutoPin ( bool on )
 }
 
 
+void qpwgraph_form::patchbayAutoDisconnect ( bool on )
+{
+	m_ui.graphCanvas->setPatchbayAutoDisconnect(on);
+
+	stabilize();
+}
+
+
 // Main menu slots.
 void qpwgraph_form::viewMenubar ( bool on )
 {
@@ -854,6 +866,33 @@ void qpwgraph_form::helpSystemTray ( bool on )
 }
 
 
+void qpwgraph_form::helpAlsaMidi ( bool on )
+{
+#ifdef CONFIG_ALSA_MIDI
+	if (on && m_alsamidi == nullptr) {
+		m_alsamidi = new qpwgraph_alsamidi(m_ui.graphCanvas);
+		QObject::connect(
+			m_alsamidi, SIGNAL(changed()),
+			this, SLOT(alsamidi_changed()));
+		++m_alsamidi_changed;
+	}
+	else
+	if (!on && m_alsamidi) {
+		m_alsamidi->clearItems();
+		QObject::disconnect(
+			m_alsamidi, SIGNAL(changed()),
+			this, SLOT(alsamidi_changed()));
+		delete m_alsamidi;
+		m_alsamidi = nullptr;
+	}
+#else
+	(void) on;
+#endif
+
+	stabilize();
+}
+
+
 void qpwgraph_form::helpAbout (void)
 {
 	static const QString title = PROJECT_NAME;
@@ -1119,7 +1158,7 @@ void qpwgraph_form::refresh (void)
 
 	if (nchanged > 0) {
 		qpwgraph_patchbay *patchbay = m_ui.graphCanvas->patchbay();
-		if (patchbay)
+		if (patchbay && patchbay->isActivated())
 			patchbay->scan();
 		stabilize();
 	}
@@ -1195,6 +1234,10 @@ void qpwgraph_form::stabilize (void)
 	m_zoom_slider->setValue(zoom_value);
 	m_zoom_spinbox->blockSignals(is_spinbox_blocked);
 	m_zoom_slider->blockSignals(is_slider_blocked);
+
+#ifdef CONFIG_ALSA_MIDI
+	m_ui.viewColorsAlsaMidiAction->setEnabled(m_alsamidi != nullptr);
+#endif
 }
 
 
@@ -1242,7 +1285,9 @@ bool qpwgraph_form::patchbayOpenFile ( const QString& path, bool clear )
 
 	m_ui.graphCanvas->patchbayEdit();
 
-	patchbay->scan();
+	if (patchbay->isActivated())
+		patchbay->scan();
+
 	return true;
 }
 
@@ -1556,12 +1601,15 @@ void qpwgraph_form::restoreState (void)
 		const bool is_activated = m_config->isPatchbayActivated();
 		const bool is_exclusive = m_config->isPatchbayExclusive();
 		const bool is_autopin = m_config->isPatchbayAutoPin();
+		const bool is_autodisconnect = m_config->isPatchbayAutoDisconnect();
 		m_ui.patchbayActivatedAction->setChecked(is_activated);
 		m_ui.patchbayExclusiveAction->setChecked(is_exclusive);
 		m_ui.patchbayAutoPinAction->setChecked(is_autopin);
+		m_ui.patchbayAutoDisconnectAction->setChecked(is_autodisconnect);
 		patchbay->setActivated(is_activated);
 		patchbay->setExclusive(is_exclusive);
 		m_ui.graphCanvas->setPatchbayAutoPin(is_autopin);
+		m_ui.graphCanvas->setPatchbayAutoDisconnect(is_autodisconnect);
 	}
 
 	m_ui.viewMenubarAction->setChecked(m_config->isMenubar());
@@ -1625,6 +1673,13 @@ void qpwgraph_form::restoreState (void)
 	m_ui.helpSystemTrayAction->setChecked(is_systray_enabled);
 	helpSystemTray(is_systray_enabled);
 #endif
+
+#ifdef CONFIG_ALSA_MIDI
+	const bool is_alsa_midi
+		= m_config->isAlsaMidiEnabled();
+	m_ui.helpAlsaMidiAction->setChecked(is_alsa_midi);
+	helpAlsaMidi(is_alsa_midi);
+#endif
 }
 
 
@@ -1646,6 +1701,7 @@ void qpwgraph_form::saveState (void)
 	m_config->setMenubar(m_ui.MenuBar->isVisible());
 
 	m_config->setPatchbayAutoPin(m_ui.patchbayAutoPinAction->isChecked());
+	m_config->setPatchbayAutoDisconnect(m_ui.patchbayAutoDisconnectAction->isChecked());
 	m_config->setPatchbayExclusive(m_ui.patchbayExclusiveAction->isChecked());
 	m_config->setPatchbayActivated(m_ui.patchbayActivatedAction->isChecked());
 	m_config->setPatchbayPath(m_patchbay_path);
@@ -1655,6 +1711,10 @@ void qpwgraph_form::saveState (void)
 	m_config->setSystemTrayEnabled(m_ui.helpSystemTrayAction->isChecked());
 #endif
 
+#ifdef CONFIG_ALSA_MIDI
+	m_config->setAlsaMidiEnabled(m_ui.helpAlsaMidiAction->isChecked());
+#endif
+
 	m_config->saveState(this);
 }
 
