@@ -114,6 +114,7 @@ protected slots:
 	void patchbayUnpin();
 
 	void patchbayAutoPin(bool on);
+	void patchbayAutoDisconnect(bool on);
 
 	// Main menu slots.
 	void viewMenubar(bool on);
@@ -138,6 +139,7 @@ protected slots:
 	void viewConnectThroughNodes(bool on);
 
 	void helpSystemTray(bool on);
+	void helpAlsaMidi(bool on);
 
 	void helpAbout();
 	void helpAboutQt();
