@@ -1,7 +1,7 @@
 // qpraph1_patchbay.h
 //
 /****************************************************************************
-   Copyright (C) 2021-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2021-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,6 +22,8 @@
 #ifndef __qpwgraph_patchbay_h
 #define __qpwgraph_patchbay_h
 
+#include "qpwgraph_item.h"
+
 #include <QString>
 #include <QList>
 #include <QHash>
@@ -31,6 +33,7 @@
 class qpwgraph_canvas;
 class qpwgraph_connect;
 class qpwgraph_port;
+class qpwgraph_node;
 
 
 //----------------------------------------------------------------------------
@@ -116,6 +119,9 @@ public:
 
 protected:
 
+	// Add a new patchbay rule item.
+	void addItem(Item *item);
+
 	// Node and port type to text helpers.
 	static uint nodeTypeFromText(const QString& text);
 	static const char *textFromNodeType(uint node_type);
@@ -141,10 +147,8 @@ inline uint qHash ( const qpwgraph_patchbay::Item& item )
 {
 	return qHash(item.node_type)
 		 ^ qHash(item.port_type)
-		 ^ qHash(item.node1)
-		 ^ qHash(item.port1)
-		 ^ qHash(item.node2)
-		 ^ qHash(item.port2);
+		 ^ qHash(item.node1 + item.port1)
+		 ^ qHash(item.node2 + item.port2);
 }
 
 
