@@ -931,7 +931,7 @@ uint qpwgraph_pipewire::otherPortType (void)
 
 // PipeWire node:port finder and creator if not existing.
 bool qpwgraph_pipewire::findNodePort (
-	uint32_t node_id, uint32_t port_id,  qpwgraph_item::Mode port_mode,
+	uint node_id, uint port_id,  qpwgraph_item::Mode port_mode,
 	qpwgraph_node **node, qpwgraph_port **port, bool add_new )
 {
 	Node *n = findNode(node_id);
@@ -964,7 +964,7 @@ bool qpwgraph_pipewire::findNodePort (
 		}
 	}
 
-	if (*node && m_recycled.value(qpwgraph_node::NodeIdKey(*node), nullptr))
+	if (*node && m_recycled_nodes.value(qpwgraph_node::NodeIdKey(*node), nullptr))
 		return false;
 
 	if (*node && n->node_changed) {
@@ -975,6 +975,9 @@ bool qpwgraph_pipewire::findNodePort (
 	if (*node)
 		*port = (*node)->findPort(port_id, port_mode, port_type);
 
+	if (*port && m_recycled_ports.value(qpwgraph_port::PortIdKey(*port), nullptr))
+		return false;
+
 	if (add_new && *node == nullptr) {
 		QString node_name = n->node_name;
 		if ((p->port_flags & Port::Physical) == Port::None) {
@@ -1089,7 +1092,8 @@ void qpwgraph_pipewire::updateItems (void)
 	//
 	qpwgraph_sect::resetItems(qpwgraph_pipewire::nodeType());
 
-	m_recycled.clear();
+	m_recycled_nodes.clear();
+	m_recycled_ports.clear();
 }
 
 
@@ -1107,7 +1111,8 @@ void qpwgraph_pipewire::clearItems (void)
 	//
 	qpwgraph_sect::clearItems(qpwgraph_pipewire::nodeType());
 
-	m_recycled.clear();
+	m_recycled_nodes.clear();
+	m_recycled_ports.clear();
 }
 
 
@@ -1290,6 +1295,8 @@ qpwgraph_pipewire::Port *qpwgraph_pipewire::createPort (
 	uint port_type,
 	uint port_flags )
 {
+	recyclePort(port_id, node_id, port_mode, port_type);
+
 	Node *node = findNode(node_id);
 	if (node == nullptr)
 		return nullptr;
@@ -1373,26 +1380,38 @@ void qpwgraph_pipewire::destroyLink ( Link *link )
 }
 
 
-// Special node recycler...
-void qpwgraph_pipewire::recycleNode (
-	uint node_id, qpwgraph_item::Mode node_mode )
+// Special node finder...
+qpwgraph_node *qpwgraph_pipewire::findNode (
+	uint node_id, qpwgraph_item::Mode node_mode ) const
 {
 	const uint node_type = qpwgraph_pipewire::nodeType();
 	qpwgraph_node *node = qpwgraph_sect::findNode(node_id, node_mode, node_type);
 	if (node == nullptr)
 		node = qpwgraph_sect::findNode(node_id, qpwgraph_item::Duplex, node_type);
+
+	return node;
+}
+
+
+// Special node recycler...
+void qpwgraph_pipewire::recycleNode (
+	uint node_id, qpwgraph_item::Mode node_mode )
+{
+	qpwgraph_node *node = findNode(node_id, node_mode);
+	if (node)
+		m_recycled_nodes.insert(qpwgraph_node::NodeIdKey(node), node);
+}
+
+
+// Special port recycler...
+void qpwgraph_pipewire::recyclePort (
+	uint port_id, uint node_id, qpwgraph_item::Mode port_mode, uint port_type )
+{
+	qpwgraph_node *node = findNode(node_id, port_mode);
 	if (node) {
-		m_recycled.insert(qpwgraph_node::NodeIdKey(node), node);
-	#if 0
-		for (qpwgraph_port *port : node->ports()) {
-			if (port->portMode() & qpwgraph_item::Output) {
-				for (qpwgraph_connect *connect : port->connects()) {
-					connect->setMarked(false);
-					connect->disconnect();
-				}
-			}
-		}
-	#endif
+		qpwgraph_port *port = node->findPort(port_id, port_mode, port_type);
+		if (port)
+			m_recycled_ports.insert(qpwgraph_port::PortIdKey(port), port);
 	}
 }
 
